@@ -20,7 +20,7 @@ from calculate.lib.cl_lang import setLocalTranslate, getLazyLocalTranslate
 from calculate.lib.cl_template import TemplatesError
 from calculate.lib.utils.binhosts import BinhostError
 from calculate.lib.utils.files import FilesError
-from calculate.update.update import UpdateError
+from ..update import UpdateError
 from calculate.lib.utils.git import GitError
 
 _ = lambda x: x
