@@ -20,17 +20,18 @@ from calculate.lib.datavars import VariableError,DataVarsError
 
 from calculate.core.server.func import WsdlBase
 from calculate.install.install import InstallError
-from calculate.update.update import Update, UpdateError
+from .update import Update, UpdateError
 from calculate.lib.utils.git import GitError
-from utils.cl_update import ClUpdateAction
-from utils.cl_update_profile import ClUpdateProfileAction
-from utils.cl_setup_update import ClSetupUpdateAction
+from .utils.cl_update import ClUpdateAction
+from .utils.cl_update_profile import ClUpdateProfileAction
+from .utils.cl_setup_update import ClSetupUpdateAction
 from calculate.lib.cl_lang import setLocalTranslate, getLazyLocalTranslate, _
 
 setLocalTranslate('cl_update3', sys.modules[__name__])
 __ = getLazyLocalTranslate(_)
 
 
+
 class Wsdl(WsdlBase):
     methods = [
         #
